==> mule-datasense-4.1.5-hf1-sources.jar: org/mule/datasense/impl/util/ExpressionLanguageUtils.java <==
package org.mule.datasense.impl.util;

import org.mule.datasense.impl.model.types.EventType;
import org.mule.datasense.impl.model.types.TypeUtils;
import org.mule.metadata.api.model.MetadataType;
import org.mule.metadata.message.api.MuleEventMetadataType;
import org.mule.metadata.message.api.MuleEventMetadataTypeBuilder;
import org.mule.metadata.message.api.el.ExpressionLanguageMetadataTypeResolver;
import org.mule.metadata.message.api.el.TypeBindings;

import java.util.Optional;

public class ExpressionLanguageUtils {

  public static final String EXPRESSION_PREFIX = "#[";
  public static final String EXPRESSION_PREFIX_MEL = "#[mel:";
  public static final String EXPRESSION_POSTFIX = "]";

  public static boolean isExpression(String value) {
    return extractExpression(value).isPresent();
  }

  public static Optional<String> extractExpression(String value) {
    Optional<String> result = Optional.empty();

    if (!(value == null || value.isEmpty())) {
      String trimmedText = value.trim();
      if (trimmedText.startsWith(EXPRESSION_PREFIX) && !trimmedText.startsWith(EXPRESSION_PREFIX_MEL)
          && trimmedText.endsWith(EXPRESSION_POSTFIX)) {
        result =
            Optional.of(trimmedText.substring(EXPRESSION_PREFIX.length(), trimmedText.length() - EXPRESSION_POSTFIX.length()));
      }
    }

    return result;
  }

  public static String toExpression(String expression) {
    return EXPRESSION_PREFIX + expression + EXPRESSION_POSTFIX;
  }

  public static MetadataType resolveExpressionType(String expression, MuleEventMetadataType muleEventMetadataType,
                                                   TypeBindings typeBindings,
                                                   ExpressionLanguageMetadataTypeResolver expressionLanguageMetadataTypeResolver,
                                                   ExpressionLanguageMetadataTypeResolver.MessageCallback messageCallback) {
    return expressionLanguageMetadataTypeResolver.getOutputType(TypeUtils.buildTypeBindings(muleEventMetadataType, typeBindings),
                                                                expression, messageCallback);
  }

  public static MetadataType resolveExpressionType(String expression, String mimeType,
                                                   MuleEventMetadataType muleEventMetadataType,
                                                   TypeBindings typeBindings,
                                                   ExpressionLanguageMetadataTypeResolver expressionLanguageMetadataTypeResolver,
                                                   ExpressionLanguageMetadataTypeResolver.MessageCallback messageCallback) {
    return expressionLanguageMetadataTypeResolver.getOutputType(TypeUtils.buildTypeBindings(muleEventMetadataType, typeBindings),
                                                                expression, mimeType, messageCallback);
  }

  public static MetadataType resolveExpressionType(String expression, EventType inputEventType, TypeBindings typeBindings,
                                                   ExpressionLanguageMetadataTypeResolver expressionLanguageMetadataTypeResolver,
                                                   ExpressionLanguageMetadataTypeResolver.MessageCallback messageCallback) {
    return resolveExpressionType(expression, TypeUtils.asMuleEventMetadataType(inputEventType).build(), typeBindings,
                                 expressionLanguageMetadataTypeResolver, messageCallback);
  }

  public static void resolveInputEventType(String expression,
                                           ExpressionLanguageMetadataTypeResolver expressionLanguageMetadataTypeResolver,
                                           MetadataType metadataType,
                                           MuleEventMetadataTypeBuilder muleEventMetadataTypeBuilder,
                                           ExpressionLanguageMetadataTypeResolver.MessageCallback messageCallback) {
    expressionLanguageMetadataTypeResolver
        .getInputType(expression, metadataType, muleEventMetadataTypeBuilder, messageCallback);
  }

}

==> mule-datasense-4.2.1-hf1-sources.jar: org/mule/datasense/impl/util/ExpressionLanguageUtils.java <==
package org.mule.datasense.impl.util;

import org.mule.datasense.impl.model.types.EventType;
import org.mule.datasense.impl.model.types.TypeUtils;
import org.mule.metadata.api.model.MetadataType;
import org.mule.metadata.message.api.MuleEventMetadataType;
import org.mule.metadata.message.api.MuleEventMetadataTypeBuilder;
import org.mule.metadata.message.api.el.TypeBindings;
import org.mule.runtime.api.metadata.ExpressionLanguageMetadataService;

import java.util.Optional;

public class ExpressionLanguageUtils {

  public static final String EXPRESSION_PREFIX = "#[";
  public static final String EXPRESSION_PREFIX_MEL = "#[mel:";
  public static final String EXPRESSION_POSTFIX = "]";

  public static boolean isExpression(String value) {
    return extractExpression(value).isPresent();
  }

  public static Optional<String> extractExpression(String value) {
    Optional<String> result = Optional.empty();

    if (!(value == null || value.isEmpty())) {
      String trimmedText = value.trim();
      if (trimmedText.startsWith(EXPRESSION_PREFIX) && !trimmedText.startsWith(EXPRESSION_PREFIX_MEL)
          && trimmedText.endsWith(EXPRESSION_POSTFIX)) {
        result =
            Optional.of(trimmedText.substring(EXPRESSION_PREFIX.length(), trimmedText.length() - EXPRESSION_POSTFIX.length()));
      }
    }

    return result;
  }

  public static String toExpression(String expression) {
    return EXPRESSION_PREFIX + expression + EXPRESSION_POSTFIX;
  }

  public static MetadataType resolveExpressionType(String expression, MuleEventMetadataType muleEventMetadataType,
                                                   TypeBindings typeBindings,
                                                   ExpressionLanguageMetadataService expressionLanguageMetadataService,
                                                   ExpressionLanguageMetadataService.MessageCallback messageCallback) {
    return expressionLanguageMetadataService.getOutputType(TypeUtils.buildTypeBindings(muleEventMetadataType, typeBindings),
                                                           expression, messageCallback);
  }

  public static MetadataType resolveExpressionType(String expression, String mimeType,
                                                   MuleEventMetadataType muleEventMetadataType,
                                                   TypeBindings typeBindings,
                                                   ExpressionLanguageMetadataService expressionLanguageMetadataService,
                                                   ExpressionLanguageMetadataService.MessageCallback messageCallback) {
    return expressionLanguageMetadataService.getOutputType(TypeUtils.buildTypeBindings(muleEventMetadataType, typeBindings),
                                                           expression, mimeType, messageCallback);
  }

  public static MetadataType resolveExpressionType(String expression, EventType inputEventType, TypeBindings typeBindings,
                                                   ExpressionLanguageMetadataService expressionLanguageMetadataService,
                                                   ExpressionLanguageMetadataService.MessageCallback messageCallback) {
    return resolveExpressionType(expression, TypeUtils.asMuleEventMetadataType(inputEventType).build(), typeBindings,
                                 expressionLanguageMetadataService, messageCallback);
  }

  public static void resolveInputEventType(String expression,
                                           ExpressionLanguageMetadataService expressionLanguageMetadataService,
                                           MetadataType metadataType,
                                           MuleEventMetadataTypeBuilder muleEventMetadataTypeBuilder,
                                           ExpressionLanguageMetadataService.MessageCallback messageCallback) {
    expressionLanguageMetadataService
        .getInputType(expression, metadataType, muleEventMetadataTypeBuilder, messageCallback);
  }

}
